@@ -330,8 +330,8 @@ namespace Model
     int m_throughput{0};
     bool m_throughputHasBeenSet = false;
 
-    Aws::String m_clientToken;
-    bool m_clientTokenHasBeenSet = false;
+    Aws::String m_clientToken{Aws::Utils::UUID::PseudoRandomUUID()};
+    bool m_clientTokenHasBeenSet = true;
 
     int m_volumeInitializationRate{0};
     bool m_volumeInitializationRateHasBeenSet = false;
