@@ -905,7 +905,62 @@ namespace Model
     p5en_48xlarge,
     f2_12xlarge,
     f2_48xlarge,
-    trn2_48xlarge
+    trn2_48xlarge,
+    c7i_flex_12xlarge,
+    c7i_flex_16xlarge,
+    m7i_flex_12xlarge,
+    m7i_flex_16xlarge,
+    i7ie_metal_24xl,
+    i7ie_metal_48xl,
+    i8g_48xlarge,
+    c8gd_medium,
+    c8gd_large,
+    c8gd_xlarge,
+    c8gd_2xlarge,
+    c8gd_4xlarge,
+    c8gd_8xlarge,
+    c8gd_12xlarge,
+    c8gd_16xlarge,
+    c8gd_24xlarge,
+    c8gd_48xlarge,
+    c8gd_metal_24xl,
+    c8gd_metal_48xl,
+    i7i_large,
+    i7i_xlarge,
+    i7i_2xlarge,
+    i7i_4xlarge,
+    i7i_8xlarge,
+    i7i_12xlarge,
+    i7i_16xlarge,
+    i7i_24xlarge,
+    i7i_48xlarge,
+    i7i_metal_24xl,
+    i7i_metal_48xl,
+    p6_b200_48xlarge,
+    m8gd_medium,
+    m8gd_large,
+    m8gd_xlarge,
+    m8gd_2xlarge,
+    m8gd_4xlarge,
+    m8gd_8xlarge,
+    m8gd_12xlarge,
+    m8gd_16xlarge,
+    m8gd_24xlarge,
+    m8gd_48xlarge,
+    m8gd_metal_24xl,
+    m8gd_metal_48xl,
+    r8gd_medium,
+    r8gd_large,
+    r8gd_xlarge,
+    r8gd_2xlarge,
+    r8gd_4xlarge,
+    r8gd_8xlarge,
+    r8gd_12xlarge,
+    r8gd_16xlarge,
+    r8gd_24xlarge,
+    r8gd_48xlarge,
+    r8gd_metal_24xl,
+    r8gd_metal_48xl
   };
 
 namespace InstanceTypeMapper
